# LiveKit Plugins Groq

Agent Framework plugin for services from Groq. Currently supporting STT, and LLM

## Installation

```bash
pip install livekit-plugins-groq
```

## Pre-requisites

For credentials, you'll need a Groq Cloud account and obtain the correct credentials. Credentials can be passed directly or via GROQ_API_KEY environment variable
